%define anolis_release 1
%global pypi_name dnspython

%bcond_with trio
%bcond_with curio
%bcond_with doh

Name:           python-dns
Version:        2.6.0
Release:        %{anolis_release}%{?dist}
Summary:        DNS toolkit for Python

# The entire package is licensed with both licenses, see LICENSE file
License:        ISC and MIT
URL:            http://www.dnspython.org

Source0:        https://files.pythonhosted.org/packages/77/4e/7ed5533779c9544b34643bf02b04c17015e6b9c2387d091b261d83283249/%{pypi_name}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-pytest
BuildRequires:  python3-hatchling
BuildRequires:  python3-wheel
BuildRequires:  python3-pip
BuildRequires:  python3-pbr

%global _description %{expand:
dnspython is a DNS toolkit for Python. It supports almost all record
types. It can be used for queries, zone transfers, and dynamic
updates. It supports TSIG authenticated messages and EDNS0.

dnspython provides both high and low level access to DNS. The high
level classes perform queries for data of a given name, type, and
class, and return an answer set. The low level classes allow direct
manipulation of DNS zones, messages, names, and records.
}

%description %_description
%package -n python3-dns
Summary:        %{summary}

%description -n python3-dns %_description

%generate_buildrequires
%pyproject_buildrequires -r %{?with_trio:-x trio} %{?with_curio:-x curio} %{?with_doh:-x doh}

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# strip exec permissions so that we don't pick up dependencies from docs
find examples -type f | xargs chmod a-x

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files dns

%check
export OPENSSL_ENABLE_SHA1_SIGNATURES=yes
%if 0
%pytest
%endif

%files -n python3-dns -f %{pyproject_files}
%license LICENSE
%doc README.md examples
%pycached %exclude %{python3_sitelib}/dns/_trio_backend.py
%pycached %exclude %{python3_sitelib}/dns/_curio_backend.py

%pyproject_extras_subpkg -n python3-dns dnssec idna

%if %{with doh}
%pyproject_extras_subpkg -n python3-dns doh
%endif

%if %{with trio}
%pyproject_extras_subpkg -n python3-dns trio
%pycached %{python3_sitelib}/dns/_trio_backend.py
%endif

%if %{with curio}
%pyproject_extras_subpkg -n python3-dns curio
%pycached %{python3_sitelib}/dns/_curio_backend.py
%endif

%changelog

* Thu May 30 2024 gaoxulin <gaoxulin@ieisystem.com> - 2.6.0-1
- fix CVE-2023-29483


* Tue Mar 26 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 2.3.0-2
- Rebuild with python3.11

* Sat Apr 8 2023 Funda Wang <fundawang@yeah.net> - 2.3.0-1
- New version 2.3.0
- Disable test as it requires valid /etc/resolv.conf, which does not
  exist in current build system

* Sat Dec 17 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.2.1-2
- rebuild with python-cryptography update

* Fri Jul 15 2022 happy_orange <songnannan@linux.alibaba.com> - 2.2.1-1
- Init pacakge from upstream
